# Built-in web application

Ragna comes with a web application where you can try out all of the features!

You can launch the web application from the CLI:

```bash
ragna ui
```

It open in a browser window automatically.

!!! tip "Under development"

    This documentation page is being actively worked on.
    It will be updated with more details soon. :)
